function [params, init, u] = initSettings()
%%% INITSETTINGS - function that returns all initial parameters values for
%%% the numerical scheme.

    %%%%--- MODEL ASSOCIATED PARAMETERS ---%%%%
    
    params.model='Ergun'; %{'Hahnfeldt', 'Ergun', 'dOnofrio'}
    
    params.angType=1;  %0 -> original model, 1 -> modified model
    
    params.eps=0.2032; %tumor growth rate: -eps*p*log(p/q)
    params.mu=0;       %spontaneous loss of functional vasculature: -mu*q
    params.d=0.0028;   %endogenous inhibition: -d*I(p,q)
    params.l=10.3915;  %stimulation: l/(a+u(t))*S(p,q)
    params.a=4.5980;   %stimulation: l/(a+u(t))*S(p,q)
    params.e=0.0273;   %drug influence: -e*u(t)*q (ONLY FOR CLASSIC FORMULATION)
    
    init=[2000; 3000]; %initial condition (p(0),q(0))

    params.Tmax=30;    %final time
    
    %%%%--- ---%%%%
    
    
    %%%%--- OPTIMAL CONTROL PROBLEM SETTINGS ---%%%%
    
    params.Ub=20;    %upper bound for control
    params.Lb=0;     %lower bound for control

    params.k1=2;     %parameter for the payoff functional: k1*Integrate(u(t))
    params.k2=1000;  %parameter for the payoff functional: -k2*q(T)/p(T)
    
    %%%%--- ---%%%%
    
    %%%%--- SOLVER SETTINGS ---%%%%
    
    %initial control
    u.ti=[0 params.Tmax];
    u.ui=[params.Ub params.Ub];
    
    params.gradTol=1e-0; %function change tolerance for the gradient method
    
    params.solTol=1e-8;  %RelTol for the ode methods
    
    %%%%--- ---%%%%

end

