function solC = solveCostateInv( sPQ,u, dS, dI, par  )
%SOLVECOSTATEINV - solving adjoint equations backward in time.

    [~,init]=payoff(sPQ.y(1,end),sPQ.y(2,end),u,par);
    
    options=odeset('RelTol',par.solTol,'Refine',10);
    
    if par.angType
        solC=ode45(@costateEqns,[par.Tmax 0],init,options);
    else
        solC=ode45(@costateEqnsClassic,[par.Tmax 0],init,options);
    end
    
    
    function dY=costateEqns(t,y) %adjoint equations for modified model
        dY=zeros(2,1);
        pq=deval(sPQ,t);
        w=par.l/(par.a+control(t,u));
        vdS=feval(dS,pq(1),pq(2));
        vdI=feval(dI,pq(1),pq(2));
        
        dY(1)=par.eps*y(1)*(log(pq(1)/pq(2))+1)-...
              y(2)*(w*vdS(1)-par.d*vdI(1));
        dY(2)=-par.eps*y(1)*pq(1)/pq(2)+...
              y(2)*(par.mu-w*vdS(2)+par.d*vdI(2));
    end

    function dY=costateEqnsClassic(t,y) %adjoint equations for original model
        dY=zeros(2,1);
        pq=deval(sPQ,t);
        w=control(t,u);
        vdS=feval(dS,pq(1),pq(2));
        vdI=feval(dI,pq(1),pq(2));
        
        dY(1)=par.eps*y(1)*(log(pq(1)/pq(2))+1)-...
              y(2)*(par.l/par.a*vdS(1)-par.d*vdI(1));
        dY(2)=-par.eps*y(1)*pq(1)/pq(2)+...
              y(2)*(par.mu-par.l/par.a*vdS(2)+par.d*vdI(2)+par.e*w);
    end
end

