function solM = solveFullSystem( S, I, dS, dI, par, init)
    
    options=odeset('RelTol',1e-10);
    
    if par.angType
        solM=ode45(@vectField,[0 par.Tmax],init,options);
    else
        solM=ode45(@vectFieldClassic,[0 par.Tmax],init,options);
    end
    
    function dY=vectField(t,x)
        u=solveHu(t,x,S,par);
        w=par.l/(par.a+u);
        
        dY=zeros(4,1);
        dY(1)=-par.eps*x(1)*log(x(1)/x(2));
        dY(2)=-par.mu*x(2)-par.d*feval(I,x(1),x(2))+...
              w*feval(S,x(1),x(2));
          
        vdS=feval(dS,x(1),x(2));
        vdI=feval(dI,x(1),x(2));
        
        
        dY(3)=par.eps*x(3)*(log(x(1)/x(2))+1)-...
              x(4)*(w*vdS(1)-par.d*vdI(1));
        dY(4)=-par.eps*x(3)*x(1)/x(2)+...
              x(4)*(par.mu-w*vdS(2)+par.d*vdI(2));
    end

    function dY=vectFieldClassic(t,x)
        w=solveHu(t,x,S,par);%control(t,u0);

        dY=zeros(4,1);
        dY(1)=-par.eps*x(1)*log(x(1)/x(2));
        dY(2)=-par.mu*x(2)-par.d*feval(I,x(1),x(2))+...
              par.l/par.a*feval(S,x(1),x(2))-w*par.e*x(2);
          
        vdS=feval(dS,x(1),x(2));
        vdI=feval(dI,x(1),x(2));
        
        dY(3)=par.eps*x(3)*(log(x(1)/x(2))+1)-...
              x(4)*(par.l/par.a*vdS(1)-par.d*vdI(1));
        dY(4)=-par.eps*x(3)*x(1)/x(2)+...
              x(4)*(par.mu-par.l/par.a*vdS(2)+par.d*vdI(2)+par.e*w);
    end

end

