function solM = solveModel( S,I,u, par, init )
%SOLVEMODEL - function returning solution to the model specified by the
%S(p,q) and I(p,q) function with the parameters in par. 

    options=odeset('RelTol',par.solTol,'Refine',10);
    
    if par.angType
        solM=ode45(@vectField,[0 par.Tmax],init,options);
    else
        solM=ode45(@vectFieldClassic,[0 par.Tmax],init,options);
    end
    
    function dY=vectField(t,x) %vector field for the modified model
        dY=zeros(2,1);
        dY(1)=-par.eps*x(1)*log(x(1)/x(2));
        dY(2)=-par.mu*x(2)-par.d*feval(I,x(1),x(2))+...
              par.l/(par.a+control(t,u))*feval(S,x(1),x(2));
    end

    function dY=vectFieldClassic(t,x) %vector field for the original model
        dY=zeros(2,1);
        dY(1)=-par.eps*x(1)*log(x(1)/x(2));
        dY(2)=-par.mu*x(2)-par.d*feval(I,x(1),x(2))+...
              par.l/par.a*feval(S,x(1),x(2))-control(t,u)*par.e*x(2);
    end

end

