function [S, I, dS, dI] = selectModel( model )
%SELECTMODEL - function returning handles to the functions defining the
%respective models (I(p,q) and S(p,q)) together with the Jacobi matrix D[I,
%S]. Defined models: 'Hahnfeldt', 'Ergun', 'dOnofrio'.

    switch model
        case 'Hahnfeldt'
            S=@(p,q)(p);
            I=@(p,q)(q.*p.^(2/3));
            dS=@(p,q)([1; 0]);
            dI=@(p,q)([2/3*q.*p.^(-1/3); p.^(2/3)]);
        case 'Ergun'
            S=@(p,q)(q.^(2/3));
            I=@(p,q)(q.^(4/3));
            dS=@(p,q)([0; 2/3*q.^(-1/3)]);
            dI=@(p,q)([0; 4/3*q.^(1/3)]);
        case 'dOnofrio'
            S=@(p,q)(q);
            I=@(p,q)(q.*p.^(2/3));
            dS=@(p,q)([0; 1]);
            dI=@(p,q)([2/3*q.*p.^(-1/3); p.^(2/3)]);
    end
    
end

