function plotControl( sol, u, inset,fig )
%PLOTCONTROL - function for drawing model solution (sol) with corresponding
%control (u). Variable inset is a 1x4 vactor describing the inset position (if
%inset=[] inset won't be drawn). Variable fig denotes the number of the
%figure to be drawn.

    %%%%--- DRAWING MODEL SOLUTION ---%%%%
    
    f=figure(fig);
    clf;
    
    axes1 = axes('Parent',f, 'FontSize', 18);
    
    plot1=plot(sol.x,sol.y,'Parent',axes1,'LineWidth',2);
    
    T=sol.x(end);
    xlim([0 T]);
    
    set(plot1(1),'DisplayName','p(t)');
    set(plot1(2),'LineStyle','--','DisplayName','q(t)');
    
    legend(axes1, 'show');
    
    xlabel('t');
    
    grid on;
    box on;
    
    %%%%--- ---%%%%
    
    %%%%--- DRAWING INSET WITH CONTROL ---%%%%
    
    if inset~=0
        axes2 = axes('Parent',f,'Position',inset,...
                     'FontWeight','bold', 'FontSize', 14);

        box(axes2,'on');
        grid(axes2,'on');

        plot(u.ti, u.ui, 'Parent', axes2, 'LineWidth',4, 'LineStyle', '-', 'Color', [1 0 0]);
        
        xlim([0 T])  
        ylabel('u(t)','FontSize',18,'FontWeight','normal');
    end
    
    %%%%--- ---%%%%
end

