%MAIN SCRIPT FOR OPTIMAL CONTROL SEARCH
clear all;

addpath('Additional functions');
addpath('Core functions');
addpath('Models');
addpath('Plot functions');

%%%%--- INITIALIZE ---%%%%
%%%% Setting all necessary parameters
    
    [par, init,u]=initSettings();

    [S, I, dS, dI] = selectModel(par.model);

%%%%--- ---%%%%

%%%%--- CALCULATING INITIAL SOLUTION AND PAYOFF ---%%%%
    
    solM=solveModel( S,I,u, par, init);
    Jinit=payoff(solM.y(1,end),solM.y(2,end),u,par);
    
    display(['Initial J value: ' num2str(Jinit)]);
    display('_____________________________');

%%%%--- --- %%%%

%%%%--- GRADIENT BASED METHOD ---%%%%
%%%% Finding initial guess for shooting method

    display('Starting gradient method...');
    niter=1; JPrev=1e10; JTmp=Jinit;
    
    while abs(JPrev-JTmp)>par.gradTol
    
        JPrev=JTmp;
            
        solC=solveCostateInv(solM,u, dS, dI, par);
        [tmesh, ~, dHu]=Hamiltonian(solM,solC,u,S,I,par);
        
        [l1, u] = findOpt(u, dHu, tmesh, S, I, par, init);
        
        solM=solveModel(S, I, u, par, init);
        JTmp=payoff(solM.y(1,end),solM.y(2,end),u,par);
        
        display(['J value after ' num2str(niter) ' iterations:' num2str(JTmp)]);
        niter=niter+1;
    end
    
    display('Tolerance met - stopping.');
    display('_____________________________');
    
%%%%--- ---%%%%

%%%%--- SHOOTING METHOD ---%%%%
%%%% Finding optimal control with shooting method
    
    display('Starting shooting method...');
    
    [x0, val, uN] = findOptShooting( S, I, dS, dI, par, init, u );
    
    display('_____________________________');

%%%%--- ---%%%%

%%%%--- DISPLAY FINAL RESULT ---%%%%
%%%% Display final procedure report

    solMFinal=solveModel( S,I,uN, par, init);

    JFinal=payoff(solMFinal.y(1,end),solMFinal.y(2,end),uN,par);
    
    display(['Final J value: ' num2str(JFinal)]);
    display(['Shooting method error: ' num2str(val)]);
    
%%%%--- ---%%%%

%%%%--- PLOT SOLUTION ---%%%%
%%%% Plot respective solution components

    plotControl(solMFinal,uN,[0.63 0.5 0.25 0.25],1);

%%%%--- ---%%%%
